# ###
# # FIGURE 1: BARPLOT OF CONSTRAINED DATA
# 
# set.seed(1)
# data.abs <- data.frame(
#   "Group A" = c(20, 5, 25),
#   "Group C" = c(20, 30, 50)
# )
# 
# data.rel <- as.data.frame(apply(data.abs, 2, function(x) x / sum(x)))
# data.rel <- reshape2::melt(data.rel)
# data.rel$index <- 1:3
# data.rel$type <- "Observed"
# 
# data.abs <- reshape2::melt(data.abs)
# data.abs$index <- 1:3
# data.abs$type <- "Absolute"
# 
# data <- rbind(data.abs, data.rel)
# 
# png("4-sim_data-viz.png", width = 6, height = 6, res = 600, units = "in")
# library(ggplot2)
# ggplot(data, aes(x = variable, weight = value)) +
#   geom_bar(aes(fill = as.factor(index))) +
#   facet_grid(type ~., scales = "free") +
#   theme_bw() +
#   xlab("Subject ID") +
#   ylab("Feature Abundance") +
#   scale_fill_brewer(palette = "Spectral") +
#   ggtitle("Absolute Abundances and the Observed Portions") +
#   labs(fill = "Feature")
# dev.off()

abs_vs_rel <- function(abs, rel, id = 1){
  
  library(ggplot2)
  
  m1 <- glmnet::cv.glmnet(as.matrix(abs), y, family = "binomial")
  m2 <- glmnet::cv.glmnet(as.matrix(rel), y, family = "binomial")
  
  # SHOW BARPLOT OF ABSOLUTE vs. RELATIVE DATA
  abs <- as.matrix(abs)
  rel <- as.matrix(rel)
  data <- data.frame(value = c(abs[1,], rel[1,], abs[N,], rel[N,]),
                     index = rep(1:ncol(abs), 4),
                     type = rep(c(rep("Absolute", ncol(abs)), rep("Relative", ncol(abs))), 2),
                     variable = c(rep("Group A", ncol(abs)*2), rep("Group B", ncol(abs)*2)))
  g1 <- ggplot(data, aes(x = variable, weight = value)) +
    geom_bar(aes(fill = as.factor(index))) +
    facet_grid(type ~., scales = "free") +
    theme_bw() +
    xlab("Group ID") +
    ylab("Feature Abundance") +
    scale_fill_brewer(palette = "Spectral") +
    ggtitle(paste0(id, "A) Within-Group Distirbutions")) +
    labs(fill = "Feature ID") + theme(legend.position = "bottom")
  
  # SHOW WHY HEATMAP IS UNRELIABLE
  minmax <- function(x) (x - min(x)) / (max(x) - min(x))
  a <- coef(m1)[-1,]
  a <- minmax(abs(a))
  b <- coef(m2)[-1,]
  b <- minmax(abs(b))
  df <- data.frame(
    "Simulation" = 1,
    "Source" = c(rep("Absolute", length(a)), rep("Relative", length(b))),
    "Feature" = rep(1:length(a), 2),
    "Weight" = c(a, b)
  )
  library(ggplot2)
  g2 <- ggplot(df, aes(x = factor(Feature), y = factor(1), fill = Weight)) + 
    facet_grid(Source~.) + geom_tile() +
    theme_bw() + scale_fill_distiller(palette = "Reds") +
    ylab("") + xlab("Feature ID") +
    ggtitle(paste0(id, "B) LASSO Weight")) +
    labs(fill = "Absolute Weight") +
    theme(legend.position = "bottom",
          axis.text.y  = element_blank(),
          axis.ticks.y  = element_blank())
  
  library(patchwork)
  g1 + g2
}

###
# SIMULATED DATA EXP 1

set.seed(1)
N <- 1000
y <- c(rep(0, N/2), rep(1, N/2))

abs <- data.frame(
  "a" = rpois(N, 200),
  "b" = rpois(N, 50) + y*rpois(N, 150),
  "c" = rpois(N, 200) + y*rpois(N, 300),
  "d" = rpois(N, 50) + y*rpois(N, 50)
)

rel <- as.data.frame(t(apply(abs, 1, function(x) x/sum(x))))

system("mkdir data-out/coda-sim")
write.csv(abs, "data-out/coda-sim/exp1-n1000-abs")
write.csv(rel, "data-out/coda-sim/exp1-n1000-rel")

library(miSciTools)
fig.save(plot(abs_vs_rel(abs, rel, id = 1)), file = "4-sim_data-coda-sim1", width = 6, height = 3)

###
# SIMULATED DATA EXP 2

set.seed(1)
N <- 1000
y <- c(rep(0, N/2), rep(1, N/2))

genes <- lapply(1:10, function(i){
  if(i == 1){
    rpois(N, 100)
  }else{
    rpois(N, 100) + y*rpois(N, 50)
  }
})

abs <- do.call("cbind", genes)
rel <- t(apply(abs, 1, function(x) x/sum(x)))

system("mkdir data-out/coda-sim")
write.csv(abs, "data-out/coda-sim/exp2-n1000-abs")
write.csv(rel, "data-out/coda-sim/exp2-n1000-rel")

library(miSciTools)
fig.save(plot(abs_vs_rel(abs, rel, id = 2)), file = "4-sim_data-coda-sim2", width = 6, height = 3)

system("convert -append 4-sim_data-coda-sim1.png 4-sim_data-coda-sim2.png 4-sim_data-coda-merged.png")
