setwd("/home/thom/Dropbox/Partners/A2I2/5-GAMMI/")
system("mkdir results-dba")
dir_data <- "data-out/dba-data/"

runPipeline <- function(e, how, ...){
  
  ss <- ctrlSplitSet(func = "splitSample", percent.include = 90)
  
  fs <- ctrlFeatureSelect(func = "fsBalance", sbp.how = "sbp.fromPBA")
  gs <- ctrlGridSearch(func = "plGrid", how = how, top = 0, fold = NULL, ...)
  boot.BalancePBA <- plMonteCarlo(e, B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  fs <- ctrlFeatureSelect(func = "fsBalance", sbp.how = "sbp.fromRandom")
  gs <- ctrlGridSearch(func = "plGrid", how = how, top = 0, fold = NULL, ...)
  boot.BalanceRandom <- plMonteCarlo(e, B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  fs <- ctrlFeatureSelect(func = "fsBalance", sbp.how = "sbp.fromPropd",
                          ternary = TRUE, ratios = TRUE)
  gs <- ctrlGridSearch(func = "plGrid", how = how, top = 0, fold = NULL, ...)
  boot.BalancePropdRatiosTern <- plMonteCarlo(e, B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  fs <- ctrlFeatureSelect(func = "fsNULL")
  gs <- ctrlGridSearch(func = "plGrid", how = how, top = 0, fold = NULL, ...)
  boot.Acomp <- plMonteCarlo(modAcomp(e), B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  fs <- ctrlFeatureSelect(func = "fsNULL")
  gs <- ctrlGridSearch(func = "plGrid", how = how, top = 0, fold = NULL, ...)
  boot.CLR <- plMonteCarlo(modCLR(e), B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  fs <- ctrlFeatureSelect(func = "fsNULL")
  gs <- ctrlGridSearch(func = "plGrid", how = "buildRF", top = 0, fold = NULL)
  boot.RF.Acomp <- plMonteCarlo(modAcomp(e), B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  fs <- ctrlFeatureSelect(func = "fsNULL")
  gs <- ctrlGridSearch(func = "plGrid", how = "buildRF", top = 0, fold = NULL)
  boot.RF.CLR <- plMonteCarlo(modCLR(e), B = 20, ctrlSS = ss, ctrlFS = fs, ctrlGS = gs)
  
  # Summarize results
  res <- list(
    "PBA" = boot.BalancePBA,
    "Random" = boot.BalanceRandom,
    "Propd-tern" = boot.BalancePropdRatiosTern,
    "Acomp" = boot.Acomp,
    "CLR" = boot.CLR,
    "RF.Acomp" = boot.RF.Acomp,
    "RF.CLR" = boot.RF.CLR
  )
  
  res.df <- lapply(1:length(res),
                   function(l) data.frame("Method" = names(res)[l], res[[l]]@summary))
  final <- do.call(plyr::rbind.fill, res.df)
  
  return(final)
}

library(exprso)
library(doMC)
registerDoMC(cores = 2)
`%+%` <- function(a, b) paste0(a, b)
files <- list.files(dir_data, full.names = TRUE)
files.base <- unique(gsub("(-x\\.csv)|(-y\\.csv)", "", files))

foreach(i = 1:length(files.base)) %dopar% {
  
  print(i)
  
  x <- read.csv(files.base[i] %+% "-x.csv", row.names = 1)
  y <- read.csv(files.base[i] %+% "-y.csv", row.names = 1)
  e <- exprso(x, y[,1])
  
  set.seed(1)
  
  final <- runPipeline(
    e, how = "buildLASSO",
    lambda = list(exp(seq(log(0.001), log(5), length.out=100)))
  )
  
  write.csv(final[,colnames(final) != "lambda"],
            "results-dba/" %+% basename(files.base[i]) %+% "-out.csv")
}
