setwd("/home/thom/Dropbox/Partners/A2I2/5-GAMMI/")

# Load in WITH ATTENTION and WITHOUT ATTENTION files separately...
new <- read.csv("results-dang/13_datasets_run20/w_attn_auc_all_lvl_5_s0_1.0_l1_0.01.csv")
new$Method <- "Our DeepCoDA (with self-explanation)"
new$dataset <- substring(new$dataset, 4)
new2 <- read.csv("results-dang/13_datasets_run20/wo_attn_auc_all_lvl_5_s0_1.0_l1_0.01.csv")
new2$Method <- "Our DeepCoDA (w/o self-explanation)"
new2$dataset <- substring(new2$dataset, 4)
new <- rbind(new, new2)

# Load in baseline experiments...
files <- list.files(c("results-dba/"), full.names = TRUE)
baselines <- lapply(files, function(x) data.frame("dataset" = basename(x), read.csv(x, row.names = 1)))
baseline <- do.call("rbind", baselines)
baseline <- baseline[baseline$Method != "Random", ]
baseline$dataset <- gsub("-out.csv", "", baseline$dataset)
baseline$dataset <- substring(baseline$dataset, 4)
baseline$auc <- baseline$valid.auc

all(new$dataset %in% baseline$dataset)
df <- plyr::rbind.fill(baseline, new)
df$Method <- gsub("RF.CLR", "Random Forest (CLR)", df$Method)
df$Method <- gsub("RF.Acomp", "Random Forest", df$Method)
df$Method <- gsub("Acomp", "LASSO", df$Method)
df$Method <- gsub("CLR$", "LASSO (CLR)", df$Method)
df$Method <- gsub("PBA", "LASSO (PBA)", df$Method)
df$Method <- gsub("Propd-tern", "LASSO (DBA)", df$Method)

# Put in order...
order <- c("LASSO", "LASSO (CLR)", "LASSO (PBA)", "LASSO (DBA)", "Random Forest", "Random Forest (CLR)",
           "Our DeepCoDA (with self-explanation)", "Our DeepCoDA (w/o self-explanation)")
df$Method <- factor(df$Method, levels = order)

# Put in order...
df$dataset <- factor(df$dataset, levels =
                       c("selbal-crohn",
                         "selbal-msm-hivonly",
                         "franzosa-mic-ibd-v-hc",
                         "franzosa-mic-cd-v-uc",
                         "franzosa-met10-ibd-v-hc",
                         "franzosa-met10-cd-v-uc",
                         "duvallet-schubert-case-v-diarrhea",
                         "duvallet-schubert-case-v-nondc",
                         "duvallet-baxter-crc-v-h",
                         "duvallet-baxter-crc-v-noncrc",
                         "brca-mirna10-ca-v-hc",
                         "brca-mirna10-her2-v-ca",
                         "brca-mirna10-lumA-v-lumB"))
df$dataset <- as.numeric(df$dataset)

library(ggplot2)
g1 <- ggplot(df, aes(x = dataset, y = auc, col = Method)) + geom_boxplot() +
  theme_bw() + facet_wrap(dataset ~., scales = "free", nrow = 2) + ylim(.5, 1) +
  scale_color_brewer(palette = "Dark2") +
  ylab("Validation Set AUC") + xlab("Data Set") +
  ggtitle("Model Performance on Discovery Set") +
  theme(text = element_text(size=18),
        plot.title = element_text(size=24),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        legend.position = "none")

library(miSciTools)
fig.save(plot(g1), "b-viz-results", width = 12, height = 5)
sink("b-viz-results.txt")
knitr::kable(wwtest(df, y = "auc", x = "Method"), "latex")
sink()
