setwd("/home/thom/Dropbox/Partners/A2I2/5-GAMMI/")

# Load in WITH ATTENTION and WITHOUT ATTENTION files separately...
files <- list.files("results-dang/5sim_datasets_run20/", full.names = TRUE)
newres <- lapply(1:length(files), function(i){
  dat <- read.csv(files[i])
  data.frame("basename" = basename(files[i]), dat)
})
new <- do.call("rbind", newres)
new$Method <- ifelse(grepl("wo_", new$basename),
                     "Our DeepCoDA (w/o self-explanation)",
                     "Our DeepCoDA (with self-explanation)")
new$dataset <- gsub("exp2-n", "", new$dataset)
new$dataset <- paste0("N=", new$dataset)

# Load in baseline experiments...
files <- list.files(c("results-5sim/"), full.names = TRUE)
baselines <- lapply(files, function(x) data.frame("dataset" = basename(x), read.csv(x, row.names = 1)))
baseline <- do.call("rbind", baselines)
baseline <- baseline[baseline$Method != "Random", ]
baseline$dataset <- gsub("-out.csv", "", baseline$dataset)
baseline$dataset <- gsub("exp2-n", "", baseline$dataset)
baseline$dataset <- paste0("N=", baseline$dataset)
baseline$auc <- baseline$valid.auc

all(new$dataset %in% baseline$dataset)
df <- plyr::rbind.fill(baseline, new)
df$Method <- gsub("RF.CLR", "Random Forest (CLR)", df$Method)
df$Method <- gsub("RF.Acomp", "Random Forest", df$Method)
df$Method <- gsub("Acomp", "LASSO", df$Method)
df$Method <- gsub("CLR$", "LASSO (CLR)", df$Method)
df$Method <- gsub("PBA", "LASSO (PBA)", df$Method)
df$Method <- gsub("Propd-tern", "LASSO (DBA)", df$Method)

# Put in order...
order <- c("LASSO", "LASSO (CLR)", "LASSO (PBA)", "LASSO (DBA)", "Random Forest", "Random Forest (CLR)",
           "Our DeepCoDA (with self-explanation)", "Our DeepCoDA (w/o self-explanation)")
df$Method <- factor(df$Method, levels = order)
df$dataset <- factor(df$dataset, levels = c("N=2000", "N=4000", "N=6000", "N=8000", "N=10000"))

library(ggplot2)
g1 <- ggplot(df, aes(x = dataset, y = auc, col = Method)) + geom_boxplot() +
  theme_bw() + facet_wrap(dataset ~., scales = "free", nrow = 2) + ylim(.97, 1) +
  scale_color_brewer(palette = "Dark2") +
  ylab("Validation Set AUC") + xlab("Data Set") +
  ggtitle("Model Performance on Simulated Data") +
  theme(text = element_text(size=18),
        plot.title = element_text(size=24),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank(),
        legend.position = "bottom")

library(miSciTools)
fig.save(plot(g1), "g-viz-5sim", width = 12, height = 5)
sink("g-viz-5sim.txt")
knitr::kable(wwtest(df, y = "auc", x = "Method"), "latex")
sink()
